@@ -166,6 +166,12 @@ impl Component<Msg, NoUserEvent> for Log {
                 self.perform(Cmd::Move(Direction::Up));
                 Some(Msg::None)
             }
+            Event::Keyboard(KeyEvent {
+                code: Key::Right, ..
+            }) => Some(Msg::Ui(UiMsg::BottomPanelRight)),
+            Event::Keyboard(KeyEvent {
+                code: Key::Left, ..
+            }) => Some(Msg::Ui(UiMsg::BottomPanelLeft)),
             Event::Keyboard(KeyEvent {
                 code: Key::PageUp, ..
             }) => {
