@@ -20,7 +20,7 @@ use tuirealm::{Component, Event, MockComponent, NoUserEvent, State, StateValue};
 use uzers::{get_group_by_gid, get_user_by_uid};
 
 pub use self::chmod::ChmodPopup;
-pub use self::goto::{GotoPopup, ATTR_FILES};
+pub use self::goto::{ATTR_FILES, GotoPopup};
 use super::super::Browser;
 use super::{Msg, PendingActionMsg, TransferMsg, UiMsg};
 use crate::explorer::FileSorting;
@@ -670,7 +670,7 @@ impl KeybindingsPopup {
                         ))
                         .add_row()
                         .add_col(TextSpan::new("<P>").bold().fg(key_color))
-                        .add_col(TextSpan::from("               Toggle log panel"))
+                        .add_col(TextSpan::from("               Toggle bottom panel"))
                         .add_row()
                         .add_col(TextSpan::new("<Q|F10>").bold().fg(key_color))
                         .add_col(TextSpan::from("           Quit termscp"))
