@@ -3,7 +3,8 @@ use std::path::{Path, PathBuf};
 
 use bytesize::ByteSize;
 use tuirealm::props::{
-    Alignment, AttrValue, Attribute, Color, PropPayload, PropValue, TableBuilder, TextSpan,
+    Alignment, AttrValue, Attribute, Color, PropPayload, PropValue, TableBuilder, TextModifiers,
+    TextSpan,
 };
 use tuirealm::{PollStrategy, Update};
 
@@ -90,7 +91,9 @@ impl FileTransferActivity {
 
     /// Set text editor to use
     pub(super) fn setup_text_editor(&self) {
-        env::set_var("EDITOR", self.config().get_text_editor());
+        unsafe {
+            env::set_var("EDITOR", self.config().get_text_editor());
+        }
     }
 
     /// Convert a path to absolute according to host explorer
@@ -225,7 +228,7 @@ impl FileTransferActivity {
                     transfer_stats
                 )
             }
-            TransferPayload::Many(entries) => {
+            TransferPayload::TransferQueue(entries) => {
                 format!(
                     "{} files has been successfully transferred ({})",
                     entries.len(),
@@ -238,6 +241,11 @@ impl FileTransferActivity {
     /// Update host bridge file list
     pub(super) fn update_host_bridge_filelist(&mut self) {
         self.reload_host_bridge_dir();
+        self.reload_host_bridge_filelist();
+    }
+
+    /// Update host bridge file list
+    pub(super) fn reload_host_bridge_filelist(&mut self) {
         // Get width
         let width = self
             .context_mut()
@@ -259,31 +267,44 @@ impl FileTransferActivity {
         let files: Vec<Vec<TextSpan>> = self
             .host_bridge()
             .iter_files()
-            .map(|x| vec![TextSpan::from(self.host_bridge().fmt_file(x))])
+            .map(|x| {
+                let mut span = TextSpan::from(self.host_bridge().fmt_file(x));
+                if self.host_bridge().enqueued().contains_key(x.path()) {
+                    span.modifiers |=
+                        TextModifiers::REVERSED | TextModifiers::UNDERLINED | TextModifiers::ITALIC;
+                }
+
+                vec![span]
+            })
             .collect();
         // Update content and title
-        assert!(self
-            .app
-            .attr(
-                &Id::ExplorerHostBridge,
-                Attribute::Content,
-                AttrValue::Table(files)
-            )
-            .is_ok());
-        assert!(self
-            .app
-            .attr(
-                &Id::ExplorerHostBridge,
-                Attribute::Title,
-                AttrValue::Title((hostname, Alignment::Left))
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .attr(
+                    &Id::ExplorerHostBridge,
+                    Attribute::Content,
+                    AttrValue::Table(files)
+                )
+                .is_ok()
+        );
+        assert!(
+            self.app
+                .attr(
+                    &Id::ExplorerHostBridge,
+                    Attribute::Title,
+                    AttrValue::Title((hostname, Alignment::Left))
+                )
+                .is_ok()
+        );
     }
 
     /// Update remote file list
     pub(super) fn update_remote_filelist(&mut self) {
         self.reload_remote_dir();
+        self.reload_remote_filelist();
+    }
 
+    pub(super) fn reload_remote_filelist(&mut self) {
         let width = self
             .context_mut()
             .terminal()
@@ -304,25 +325,35 @@ impl FileTransferActivity {
         let files: Vec<Vec<TextSpan>> = self
             .remote()
             .iter_files()
-            .map(|x| vec![TextSpan::from(self.remote().fmt_file(x))])
+            .map(|x| {
+                let mut span = TextSpan::from(self.remote().fmt_file(x));
+                if self.remote().enqueued().contains_key(x.path()) {
+                    span.modifiers |=
+                        TextModifiers::REVERSED | TextModifiers::UNDERLINED | TextModifiers::ITALIC;
+                }
+
+                vec![span]
+            })
             .collect();
         // Update content and title
-        assert!(self
-            .app
-            .attr(
-                &Id::ExplorerRemote,
-                Attribute::Content,
-                AttrValue::Table(files)
-            )
-            .is_ok());
-        assert!(self
-            .app
-            .attr(
-                &Id::ExplorerRemote,
-                Attribute::Title,
-                AttrValue::Title((hostname, Alignment::Left))
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .attr(
+                    &Id::ExplorerRemote,
+                    Attribute::Content,
+                    AttrValue::Table(files)
+                )
+                .is_ok()
+        );
+        assert!(
+            self.app
+                .attr(
+                    &Id::ExplorerRemote,
+                    Attribute::Title,
+                    AttrValue::Title((hostname, Alignment::Left))
+                )
+                .is_ok()
+        );
     }
 
     /// Update log box
@@ -361,61 +392,67 @@ impl FileTransferActivity {
                 .add_col(TextSpan::from("]: "))
                 .add_col(TextSpan::from(record.msg.as_str()));
         }
-        assert!(self
-            .app
-            .attr(
-                &Id::Log,
-                Attribute::Content,
-                AttrValue::Table(table.build())
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .attr(
+                    &Id::Log,
+                    Attribute::Content,
+                    AttrValue::Table(table.build())
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn update_progress_bar(&mut self, filename: String) {
-        assert!(self
-            .app
-            .attr(
-                &Id::ProgressBarFull,
-                Attribute::Text,
-                AttrValue::String(self.transfer.full.to_string())
-            )
-            .is_ok());
-        assert!(self
-            .app
-            .attr(
-                &Id::ProgressBarFull,
-                Attribute::Value,
-                AttrValue::Payload(PropPayload::One(PropValue::F64(
-                    self.transfer.full.calc_progress()
-                )))
-            )
-            .is_ok());
-        assert!(self
-            .app
-            .attr(
-                &Id::ProgressBarPartial,
-                Attribute::Text,
-                AttrValue::String(self.transfer.partial.to_string())
-            )
-            .is_ok());
-        assert!(self
-            .app
-            .attr(
-                &Id::ProgressBarPartial,
-                Attribute::Value,
-                AttrValue::Payload(PropPayload::One(PropValue::F64(
-                    self.transfer.partial.calc_progress()
-                )))
-            )
-            .is_ok());
-        assert!(self
-            .app
-            .attr(
-                &Id::ProgressBarPartial,
-                Attribute::Title,
-                AttrValue::Title((filename, Alignment::Center))
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .attr(
+                    &Id::ProgressBarFull,
+                    Attribute::Text,
+                    AttrValue::String(self.transfer.full.to_string())
+                )
+                .is_ok()
+        );
+        assert!(
+            self.app
+                .attr(
+                    &Id::ProgressBarFull,
+                    Attribute::Value,
+                    AttrValue::Payload(PropPayload::One(PropValue::F64(
+                        self.transfer.full.calc_progress()
+                    )))
+                )
+                .is_ok()
+        );
+        assert!(
+            self.app
+                .attr(
+                    &Id::ProgressBarPartial,
+                    Attribute::Text,
+                    AttrValue::String(self.transfer.partial.to_string())
+                )
+                .is_ok()
+        );
+        assert!(
+            self.app
+                .attr(
+                    &Id::ProgressBarPartial,
+                    Attribute::Value,
+                    AttrValue::Payload(PropPayload::One(PropValue::F64(
+                        self.transfer.partial.calc_progress()
+                    )))
+                )
+                .is_ok()
+        );
+        assert!(
+            self.app
+                .attr(
+                    &Id::ProgressBarPartial,
+                    Attribute::Title,
+                    AttrValue::Title((filename, Alignment::Center))
+                )
+                .is_ok()
+        );
     }
 
     /// Finalize find process
@@ -448,16 +485,24 @@ impl FileTransferActivity {
             .found()
             .unwrap()
             .iter_files()
-            .map(|x| vec![TextSpan::from(self.found().unwrap().fmt_file(x))])
+            .map(|x| {
+                let mut span = TextSpan::from(self.found().unwrap().fmt_file(x));
+                if self.found().unwrap().enqueued().contains_key(x.path()) {
+                    span.modifiers |=
+                        TextModifiers::REVERSED | TextModifiers::UNDERLINED | TextModifiers::ITALIC;
+                }
+                vec![span]
+            })
             .collect();
-        assert!(self
-            .app
-            .attr(
-                &Id::ExplorerFind,
-                Attribute::Content,
-                AttrValue::Table(files)
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .attr(
+                    &Id::ExplorerFind,
+                    Attribute::Content,
+                    AttrValue::Table(files)
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn update_browser_file_list(&mut self) {
@@ -469,6 +514,15 @@ impl FileTransferActivity {
         }
     }
 
+    pub(super) fn reload_browser_file_list(&mut self) {
+        match self.browser.tab() {
+            FileExplorerTab::HostBridge | FileExplorerTab::FindHostBridge => {
+                self.reload_host_bridge_filelist()
+            }
+            FileExplorerTab::Remote | FileExplorerTab::FindRemote => self.reload_remote_filelist(),
+        }
+    }
+
     pub(super) fn update_browser_file_list_swapped(&mut self) {
         match self.browser.tab() {
             FileExplorerTab::HostBridge | FileExplorerTab::FindHostBridge => {
