@@ -28,7 +28,7 @@ use session::TransferPayload;
 use tempfile::TempDir;
 use tuirealm::{Application, EventListenerCfg, NoUserEvent};
 
-use super::{Activity, Context, ExitReason, CROSSTERM_MAX_POLL};
+use super::{Activity, CROSSTERM_MAX_POLL, Context, ExitReason};
 use crate::config::themes::Theme;
 use crate::explorer::{FileExplorer, FileSorting};
 use crate::filetransfer::{
@@ -40,6 +40,12 @@ use crate::system::watcher::FsWatcher;
 
 // -- components
 
+#[derive(Debug, Eq, PartialEq, Clone, Copy)]
+pub enum MarkQueue {
+    Local,
+    Remote,
+}
+
 #[derive(Debug, Eq, PartialEq, Clone, Hash)]
 enum Id {
     ChmodPopup,
@@ -74,6 +80,8 @@ enum Id {
     StatusBarRemote,
     SymlinkPopup,
     SyncBrowsingMkdirPopup,
+    TransferQueueHostBridge,
+    TransferQueueRemote,
     WaitPopup,
     WatchedPathsList,
     WatcherPopup,
@@ -125,6 +133,8 @@ enum TransferMsg {
 
 #[derive(Debug, PartialEq)]
 enum UiMsg {
+    BottomPanelLeft,
+    BottomPanelRight,
     ChangeFileSorting(FileSorting),
     ChangeTransferWindow,
     CloseChmodPopup,
@@ -153,6 +163,13 @@ enum UiMsg {
     FilterFiles(String),
     FuzzySearch(String),
     LogBackTabbed,
+    /// Mark file on the list; usize is the index of the file
+    MarkFile(usize),
+    MarkRemove(MarkQueue, PathBuf),
+    /// Mark all file at tab
+    MarkAll,
+    /// Clear all marks
+    MarkClear,
     Quit,
     ReplacePopupTabbed,
     ShowChmodPopup,
@@ -165,7 +182,7 @@ enum UiMsg {
     ShowFilterPopup,
     ShowGotoPopup,
     ShowKeybindingsPopup,
-    ShowLogPanel,
+    GoToTransferQueue,
     ShowMkdirPopup,
     ShowNewFilePopup,
     ShowOpenWithPopup,
@@ -243,14 +260,14 @@ impl FileTransferActivity {
         host_bridge_params: HostBridgeParams,
         remote_params: &FileTransferParams,
         ticks: Duration,
-    ) -> Self {
+    ) -> Result<Self, String> {
         // Get config client
         let config_client: ConfigClient = Self::init_config_client();
         // init host bridge
-        let host_bridge = HostBridgeBuilder::build(host_bridge_params, &config_client);
+        let host_bridge = HostBridgeBuilder::build(host_bridge_params, &config_client)?;
         let host_bridge_connected = host_bridge.is_localhost();
         let enable_fs_watcher = host_bridge.is_localhost();
-        Self {
+        Ok(Self {
             exit_reason: None,
             context: None,
             app: Application::init(
@@ -264,7 +281,7 @@ impl FileTransferActivity {
                 remote_params.protocol,
                 remote_params.params.clone(),
                 &config_client,
-            ),
+            )?,
             browser: Browser::new(&config_client),
             log_records: VecDeque::with_capacity(256), // 256 events is enough I guess
             walkdir: WalkdirStates::default(),
@@ -280,7 +297,7 @@ impl FileTransferActivity {
             },
             host_bridge_connected,
             remote_connected: false,
-        }
+        })
     }
 
     fn host_bridge(&self) -> &FileExplorer {
@@ -307,6 +324,45 @@ impl FileTransferActivity {
         self.browser.found_mut()
     }
 
+    /// Enqueue a file to be transferred
+    fn enqueue_file(&mut self, index: usize) {
+        let Some(src) = self
+            .browser
+            .explorer()
+            .get(index)
+            .map(|item| item.path().to_path_buf())
+        else {
+            return;
+        };
+
+        if self.browser.explorer().enqueued().contains_key(&src) {
+            debug!("File already marked, unmarking {}", src.display());
+            self.browser.explorer_mut().dequeue(&src);
+        } else {
+            debug!("Marking file {}", src.display());
+            let dest = self.browser.other_explorer_no_found().wrkdir.clone();
+            self.browser.explorer_mut().enqueue(&src, &dest);
+        }
+        self.reload_browser_file_list();
+        self.refresh_host_bridge_transfer_queue();
+        self.refresh_remote_transfer_queue();
+    }
+
+    fn enqueue_all(&mut self) {
+        let dest = self.browser.other_explorer_no_found().wrkdir.clone();
+        self.browser.explorer_mut().enqueue_all(&dest);
+        self.reload_browser_file_list();
+        self.refresh_host_bridge_transfer_queue();
+        self.refresh_remote_transfer_queue();
+    }
+
+    fn clear_queue(&mut self) {
+        self.browser.explorer_mut().clear_queue();
+        self.reload_browser_file_list();
+        self.refresh_host_bridge_transfer_queue();
+        self.refresh_remote_transfer_queue();
+    }
+
     /// Get file name for a file in cache
     fn get_cache_tmp_name(&self, name: &str, file_type: Option<&str>) -> Option<String> {
         self.cache.as_ref().map(|_| {
@@ -359,7 +415,6 @@ impl FileTransferActivity {
  * Keep it clean :)
  * Use methods instead!
  */
-
 impl Activity for FileTransferActivity {
     /// `on_create` is the function which must be called to initialize the activity.
     /// `on_create` must initialize all the data structures used by the activity
