@@ -14,8 +14,9 @@ use unicode_width::UnicodeWidthStr;
 
 use super::browser::{FileExplorerTab, FoundExplorerTab};
 use super::components::ATTR_FILES;
-use super::{components, Context, FileTransferActivity, Id};
+use super::{Context, FileTransferActivity, Id, components};
 use crate::explorer::FileSorting;
+use crate::ui::activities::filetransfer::MarkQueue;
 use crate::utils::ui::{Popup, Size};
 
 impl FileTransferActivity {
@@ -33,50 +34,56 @@ impl FileTransferActivity {
         let key_color = self.theme().misc_keys;
         let log_panel = self.theme().transfer_log_window;
         let log_background = self.theme().transfer_log_background;
-        assert!(self
-            .app
-            .mount(
-                Id::FooterBar,
-                Box::new(components::FooterBar::new(key_color)),
-                vec![]
-            )
-            .is_ok());
-        assert!(self
-            .app
-            .mount(
-                Id::ExplorerHostBridge,
-                Box::new(components::ExplorerLocal::new(
-                    "",
-                    &[],
-                    local_explorer_background,
-                    local_explorer_foreground,
-                    local_explorer_highlighted
-                )),
-                vec![]
-            )
-            .is_ok());
-        assert!(self
-            .app
-            .mount(
-                Id::ExplorerRemote,
-                Box::new(components::ExplorerRemote::new(
-                    "",
-                    &[],
-                    remote_explorer_background,
-                    remote_explorer_foreground,
-                    remote_explorer_highlighted
-                )),
-                vec![]
-            )
-            .is_ok());
-        assert!(self
-            .app
-            .mount(
-                Id::Log,
-                Box::new(components::Log::new(vec![], log_panel, log_background)),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .mount(
+                    Id::FooterBar,
+                    Box::new(components::FooterBar::new(key_color)),
+                    vec![]
+                )
+                .is_ok()
+        );
+        assert!(
+            self.app
+                .mount(
+                    Id::ExplorerHostBridge,
+                    Box::new(components::ExplorerLocal::new(
+                        "",
+                        &[],
+                        local_explorer_background,
+                        local_explorer_foreground,
+                        local_explorer_highlighted
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
+        assert!(
+            self.app
+                .mount(
+                    Id::ExplorerRemote,
+                    Box::new(components::ExplorerRemote::new(
+                        "",
+                        &[],
+                        remote_explorer_background,
+                        remote_explorer_foreground,
+                        remote_explorer_highlighted
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
+        assert!(
+            self.app
+                .mount(
+                    Id::Log,
+                    Box::new(components::Log::new(vec![], log_panel, log_background)),
+                    vec![]
+                )
+                .is_ok()
+        );
+        self.refresh_host_bridge_transfer_queue();
+        self.refresh_remote_transfer_queue();
         // Load status bar
         self.refresh_local_status_bar();
         self.refresh_remote_status_bar();
@@ -134,6 +141,17 @@ impl FileTransferActivity {
                 .direction(Direction::Horizontal)
                 .horizontal_margin(1)
                 .split(bottom_chunks[0]);
+            let bottom_components = Layout::default()
+                .constraints(
+                    [
+                        Constraint::Percentage(25),
+                        Constraint::Percentage(25),
+                        Constraint::Percentage(50),
+                    ]
+                    .as_ref(),
+                )
+                .direction(Direction::Horizontal)
+                .split(bottom_chunks[1]);
             // Draw footer
             self.app.view(&Id::FooterBar, f, body[1]);
             // Draw explorers
@@ -149,8 +167,13 @@ impl FileTransferActivity {
             } else {
                 self.app.view(&Id::ExplorerRemote, f, tabs_chunks[1]);
             }
+            // draw transfer queues
+            self.app
+                .view(&Id::TransferQueueHostBridge, f, bottom_components[0]);
+            self.app
+                .view(&Id::TransferQueueRemote, f, bottom_components[1]);
             // Draw log box
-            self.app.view(&Id::Log, f, bottom_chunks[1]);
+            self.app.view(&Id::Log, f, bottom_components[2]);
             // Draw status bar
             self.app
                 .view(&Id::StatusBarHostBridge, f, status_bar_chunks[0]);
@@ -339,14 +362,15 @@ impl FileTransferActivity {
     pub(super) fn mount_info<S: AsRef<str>>(&mut self, text: S) {
         // Mount
         let info_color = self.theme().misc_info_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::ErrorPopup,
-                Box::new(components::ErrorPopup::new(text, info_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::ErrorPopup,
+                    Box::new(components::ErrorPopup::new(text, info_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::ErrorPopup).is_ok());
     }
 
@@ -354,14 +378,15 @@ impl FileTransferActivity {
     pub(super) fn mount_error<S: AsRef<str>>(&mut self, text: S) {
         // Mount
         let error_color = self.theme().misc_error_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::ErrorPopup,
-                Box::new(components::ErrorPopup::new(text, error_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::ErrorPopup,
+                    Box::new(components::ErrorPopup::new(text, error_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::ErrorPopup).is_ok());
     }
 
@@ -374,14 +399,15 @@ impl FileTransferActivity {
         self.umount_wait();
         // Mount
         let error_color = self.theme().misc_error_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::FatalPopup,
-                Box::new(components::FatalPopup::new(text, error_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::FatalPopup,
+                    Box::new(components::FatalPopup::new(text, error_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::FatalPopup).is_ok());
     }
 
@@ -392,30 +418,32 @@ impl FileTransferActivity {
 
     pub(super) fn mount_wait<S: AsRef<str>>(&mut self, text: S) {
         let color = self.theme().misc_info_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::WaitPopup,
-                Box::new(components::WaitPopup::new(text, color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::WaitPopup,
+                    Box::new(components::WaitPopup::new(text, color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::WaitPopup).is_ok());
     }
 
     pub(super) fn mount_walkdir_wait(&mut self) {
         let color = self.theme().misc_info_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::WaitPopup,
-                Box::new(components::WalkdirWaitPopup::new(
-                    "Scanning current directory…",
-                    color
-                )),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::WaitPopup,
+                    Box::new(components::WalkdirWaitPopup::new(
+                        "Scanning current directory…",
+                        color
+                    )),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::WaitPopup).is_ok());
 
         self.view();
@@ -448,14 +476,15 @@ impl FileTransferActivity {
     pub(super) fn mount_quit(&mut self) {
         // Protocol
         let quit_color = self.theme().misc_quit_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::QuitPopup,
-                Box::new(components::QuitPopup::new(quit_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::QuitPopup,
+                    Box::new(components::QuitPopup::new(quit_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::QuitPopup).is_ok());
     }
 
@@ -468,14 +497,15 @@ impl FileTransferActivity {
     pub(super) fn mount_disconnect(&mut self) {
         // Protocol
         let quit_color = self.theme().misc_quit_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::DisconnectPopup,
-                Box::new(components::DisconnectPopup::new(quit_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::DisconnectPopup,
+                    Box::new(components::DisconnectPopup::new(quit_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::DisconnectPopup).is_ok());
     }
 
@@ -487,14 +517,15 @@ impl FileTransferActivity {
     pub(super) fn mount_chmod(&mut self, mode: UnixPex, title: String) {
         // Mount
         let color = self.theme().misc_input_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::ChmodPopup,
-                Box::new(components::ChmodPopup::new(mode, color, title)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::ChmodPopup,
+                    Box::new(components::ChmodPopup::new(mode, color, title)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::ChmodPopup).is_ok());
     }
 
@@ -508,27 +539,29 @@ impl FileTransferActivity {
 
     pub(super) fn mount_filter(&mut self) {
         let input_color = self.theme().misc_input_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::FilterPopup,
-                Box::new(components::FilterPopup::new(input_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::FilterPopup,
+                    Box::new(components::FilterPopup::new(input_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::FilterPopup).is_ok());
     }
 
     pub(super) fn mount_copy(&mut self) {
         let input_color = self.theme().misc_input_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::CopyPopup,
-                Box::new(components::CopyPopup::new(input_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::CopyPopup,
+                    Box::new(components::CopyPopup::new(input_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::CopyPopup).is_ok());
     }
 
@@ -538,14 +571,15 @@ impl FileTransferActivity {
 
     pub(super) fn mount_exec(&mut self) {
         let input_color = self.theme().misc_input_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::ExecPopup,
-                Box::new(components::ExecPopup::new(input_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::ExecPopup,
+                    Box::new(components::ExecPopup::new(input_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::ExecPopup).is_ok());
     }
 
@@ -569,30 +603,31 @@ impl FileTransferActivity {
         };
 
         // Mount component
-        assert!(self
-            .app
-            .remount(
-                Id::ExplorerFind,
-                if fuzzy_search {
-                    Box::new(components::ExplorerFuzzy::new(
-                        msg.to_string(),
-                        &[],
-                        bg,
-                        fg,
-                        hg,
-                    ))
-                } else {
-                    Box::new(components::ExplorerFind::new(
-                        msg.to_string(),
-                        &[],
-                        bg,
-                        fg,
-                        hg,
-                    ))
-                },
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::ExplorerFind,
+                    if fuzzy_search {
+                        Box::new(components::ExplorerFuzzy::new(
+                            msg.to_string(),
+                            &[],
+                            bg,
+                            fg,
+                            hg,
+                        ))
+                    } else {
+                        Box::new(components::ExplorerFind::new(
+                            msg.to_string(),
+                            &[],
+                            bg,
+                            fg,
+                            hg,
+                        ))
+                    },
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::ExplorerFind).is_ok());
     }
 
@@ -611,14 +646,15 @@ impl FileTransferActivity {
             .collect::<Vec<String>>();
 
         let input_color = self.theme().misc_input_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::GotoPopup,
-                Box::new(components::GotoPopup::new(input_color, files)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::GotoPopup,
+                    Box::new(components::GotoPopup::new(input_color, files)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::GotoPopup).is_ok());
     }
 
@@ -641,14 +677,15 @@ impl FileTransferActivity {
 
     pub(super) fn mount_mkdir(&mut self) {
         let input_color = self.theme().misc_input_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::MkdirPopup,
-                Box::new(components::MkdirPopup::new(input_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::MkdirPopup,
+                    Box::new(components::MkdirPopup::new(input_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::MkdirPopup).is_ok());
     }
 
@@ -658,14 +695,15 @@ impl FileTransferActivity {
 
     pub(super) fn mount_newfile(&mut self) {
         let input_color = self.theme().misc_input_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::NewfilePopup,
-                Box::new(components::NewfilePopup::new(input_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::NewfilePopup,
+                    Box::new(components::NewfilePopup::new(input_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::NewfilePopup).is_ok());
     }
 
@@ -675,14 +713,15 @@ impl FileTransferActivity {
 
     pub(super) fn mount_openwith(&mut self) {
         let input_color = self.theme().misc_input_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::OpenWithPopup,
-                Box::new(components::OpenWithPopup::new(input_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::OpenWithPopup,
+                    Box::new(components::OpenWithPopup::new(input_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::OpenWithPopup).is_ok());
     }
 
@@ -692,14 +731,15 @@ impl FileTransferActivity {
 
     pub(super) fn mount_rename(&mut self) {
         let input_color = self.theme().misc_input_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::RenamePopup,
-                Box::new(components::RenamePopup::new(input_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::RenamePopup,
+                    Box::new(components::RenamePopup::new(input_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::RenamePopup).is_ok());
     }
 
@@ -709,14 +749,15 @@ impl FileTransferActivity {
 
     pub(super) fn mount_saveas(&mut self) {
         let input_color = self.theme().misc_input_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::SaveAsPopup,
-                Box::new(components::SaveAsPopup::new(input_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::SaveAsPopup,
+                    Box::new(components::SaveAsPopup::new(input_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::SaveAsPopup).is_ok());
     }
 
@@ -727,32 +768,34 @@ impl FileTransferActivity {
     pub(super) fn mount_progress_bar(&mut self, root_name: String) {
         let prog_color_full = self.theme().transfer_progress_bar_full;
         let prog_color_partial = self.theme().transfer_progress_bar_partial;
-        assert!(self
-            .app
-            .remount(
-                Id::ProgressBarFull,
-                Box::new(components::ProgressBarFull::new(
-                    0.0,
-                    "",
-                    &root_name,
-                    prog_color_full
-                )),
-                vec![],
-            )
-            .is_ok());
-        assert!(self
-            .app
-            .remount(
-                Id::ProgressBarPartial,
-                Box::new(components::ProgressBarPartial::new(
-                    0.0,
-                    "",
-                    "Please wait",
-                    prog_color_partial
-                )),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::ProgressBarFull,
+                    Box::new(components::ProgressBarFull::new(
+                        0.0,
+                        "",
+                        &root_name,
+                        prog_color_full
+                    )),
+                    vec![],
+                )
+                .is_ok()
+        );
+        assert!(
+            self.app
+                .remount(
+                    Id::ProgressBarPartial,
+                    Box::new(components::ProgressBarPartial::new(
+                        0.0,
+                        "",
+                        "Please wait",
+                        prog_color_partial
+                    )),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::ProgressBarPartial).is_ok());
     }
 
@@ -768,14 +811,15 @@ impl FileTransferActivity {
             FileExplorerTab::Remote => self.remote().get_file_sorting(),
             _ => return,
         };
-        assert!(self
-            .app
-            .remount(
-                Id::SortingPopup,
-                Box::new(components::SortingPopup::new(sorting, sorting_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::SortingPopup,
+                    Box::new(components::SortingPopup::new(sorting, sorting_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::SortingPopup).is_ok());
     }
 
@@ -785,14 +829,15 @@ impl FileTransferActivity {
 
     pub(super) fn mount_radio_delete(&mut self) {
         let warn_color = self.theme().misc_warn_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::DeletePopup,
-                Box::new(components::DeletePopup::new(warn_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::DeletePopup,
+                    Box::new(components::DeletePopup::new(warn_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::DeletePopup).is_ok());
     }
 
@@ -802,16 +847,17 @@ impl FileTransferActivity {
 
     pub(super) fn mount_radio_watch(&mut self, watch: bool, local: &str, remote: &str) {
         let info_color = self.theme().misc_info_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::WatcherPopup,
-                Box::new(components::WatcherPopup::new(
-                    watch, local, remote, info_color
-                )),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::WatcherPopup,
+                    Box::new(components::WatcherPopup::new(
+                        watch, local, remote, info_color
+                    )),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::WatcherPopup).is_ok());
     }
 
@@ -821,14 +867,15 @@ impl FileTransferActivity {
 
     pub(super) fn mount_watched_paths_list(&mut self, paths: &[std::path::PathBuf]) {
         let info_color = self.theme().misc_info_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::WatchedPathsList,
-                Box::new(components::WatchedPathsList::new(paths, info_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::WatchedPathsList,
+                    Box::new(components::WatchedPathsList::new(paths, info_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::WatchedPathsList).is_ok());
     }
 
@@ -838,35 +885,38 @@ impl FileTransferActivity {
 
     pub(super) fn mount_radio_replace(&mut self, file_name: &str) {
         let warn_color = self.theme().misc_warn_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::ReplacePopup,
-                Box::new(components::ReplacePopup::new(Some(file_name), warn_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::ReplacePopup,
+                    Box::new(components::ReplacePopup::new(Some(file_name), warn_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::ReplacePopup).is_ok());
     }
 
     pub(super) fn mount_radio_replace_many(&mut self, files: &[String]) {
         let warn_color = self.theme().misc_warn_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::ReplacingFilesListPopup,
-                Box::new(components::ReplacingFilesListPopup::new(files, warn_color)),
-                vec![],
-            )
-            .is_ok());
-        assert!(self
-            .app
-            .remount(
-                Id::ReplacePopup,
-                Box::new(components::ReplacePopup::new(None, warn_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::ReplacingFilesListPopup,
+                    Box::new(components::ReplacingFilesListPopup::new(files, warn_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
+        assert!(
+            self.app
+                .remount(
+                    Id::ReplacePopup,
+                    Box::new(components::ReplacePopup::new(None, warn_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::ReplacePopup).is_ok());
     }
 
@@ -881,14 +931,15 @@ impl FileTransferActivity {
     }
 
     pub(super) fn mount_file_info(&mut self, file: &File) {
-        assert!(self
-            .app
-            .remount(
-                Id::FileInfoPopup,
-                Box::new(components::FileInfoPopup::new(file)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::FileInfoPopup,
+                    Box::new(components::FileInfoPopup::new(file)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::FileInfoPopup).is_ok());
     }
 
@@ -896,52 +947,105 @@ impl FileTransferActivity {
         let _ = self.app.umount(&Id::FileInfoPopup);
     }
 
+    pub(super) fn refresh_host_bridge_transfer_queue(&mut self) {
+        let enqueued = self
+            .host_bridge()
+            .enqueued()
+            .iter()
+            .map(|(src, dest)| (src.clone(), dest.clone()))
+            .collect::<Vec<_>>();
+        let log_panel = self.theme().transfer_log_window;
+
+        assert!(
+            self.app
+                .remount(
+                    Id::TransferQueueHostBridge,
+                    Box::new(components::SelectedFilesList::new(
+                        &enqueued,
+                        MarkQueue::Local,
+                        log_panel,
+                        "Host Bridge selected files",
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
+    }
+
+    pub(super) fn refresh_remote_transfer_queue(&mut self) {
+        let enqueued = self
+            .remote()
+            .enqueued()
+            .iter()
+            .map(|(src, dest)| (src.clone(), dest.clone()))
+            .collect::<Vec<_>>();
+        let log_panel = self.theme().transfer_log_window;
+
+        assert!(
+            self.app
+                .remount(
+                    Id::TransferQueueRemote,
+                    Box::new(components::SelectedFilesList::new(
+                        &enqueued,
+                        MarkQueue::Remote,
+                        log_panel,
+                        "Remote transfer selected files",
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
+    }
+
     pub(super) fn refresh_local_status_bar(&mut self) {
         let sorting_color = self.theme().transfer_status_sorting;
         let hidden_color = self.theme().transfer_status_hidden;
-        assert!(self
-            .app
-            .remount(
-                Id::StatusBarHostBridge,
-                Box::new(components::StatusBarLocal::new(
-                    &self.browser,
-                    sorting_color,
-                    hidden_color
-                )),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::StatusBarHostBridge,
+                    Box::new(components::StatusBarLocal::new(
+                        &self.browser,
+                        sorting_color,
+                        hidden_color
+                    )),
+                    vec![],
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn refresh_remote_status_bar(&mut self) {
         let sorting_color = self.theme().transfer_status_sorting;
         let hidden_color = self.theme().transfer_status_hidden;
         let sync_color = self.theme().transfer_status_sync_browsing;
-        assert!(self
-            .app
-            .remount(
-                Id::StatusBarRemote,
-                Box::new(components::StatusBarRemote::new(
-                    &self.browser,
-                    sorting_color,
-                    hidden_color,
-                    sync_color
-                )),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::StatusBarRemote,
+                    Box::new(components::StatusBarRemote::new(
+                        &self.browser,
+                        sorting_color,
+                        hidden_color,
+                        sync_color
+                    )),
+                    vec![],
+                )
+                .is_ok()
+        );
     }
 
     pub(super) fn mount_symlink(&mut self) {
         let input_color = self.theme().misc_input_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::SymlinkPopup,
-                Box::new(components::SymlinkPopup::new(input_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::SymlinkPopup,
+                    Box::new(components::SymlinkPopup::new(input_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::SymlinkPopup).is_ok());
     }
 
@@ -951,14 +1055,15 @@ impl FileTransferActivity {
 
     pub(super) fn mount_sync_browsing_mkdir_popup(&mut self, dir_name: &str) {
         let color = self.theme().misc_info_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::SyncBrowsingMkdirPopup,
-                Box::new(components::SyncBrowsingMkdirPopup::new(color, dir_name,)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::SyncBrowsingMkdirPopup,
+                    Box::new(components::SyncBrowsingMkdirPopup::new(color, dir_name,)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::SyncBrowsingMkdirPopup).is_ok());
     }
 
@@ -969,14 +1074,15 @@ impl FileTransferActivity {
     /// Mount help
     pub(super) fn mount_help(&mut self) {
         let key_color = self.theme().misc_keys;
-        assert!(self
-            .app
-            .remount(
-                Id::KeybindingsPopup,
-                Box::new(components::KeybindingsPopup::new(key_color)),
-                vec![],
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::KeybindingsPopup,
+                    Box::new(components::KeybindingsPopup::new(key_color)),
+                    vec![],
+                )
+                .is_ok()
+        );
         assert!(self.app.active(&Id::KeybindingsPopup).is_ok());
     }
 
@@ -1018,51 +1124,52 @@ impl FileTransferActivity {
     // -- global listener
 
     fn mount_global_listener(&mut self) {
-        assert!(self
-            .app
-            .mount(
-                Id::GlobalListener,
-                Box::<components::GlobalListener>::default(),
-                vec![
-                    Sub::new(
-                        SubEventClause::Keyboard(KeyEvent {
-                            code: Key::Esc,
-                            modifiers: KeyModifiers::NONE,
-                        }),
-                        Self::no_popup_mounted_clause(),
-                    ),
-                    Sub::new(
-                        SubEventClause::Keyboard(KeyEvent {
-                            code: Key::Char('h'),
-                            modifiers: KeyModifiers::NONE,
-                        }),
-                        Self::no_popup_mounted_clause(),
-                    ),
-                    Sub::new(
-                        SubEventClause::Keyboard(KeyEvent {
-                            code: Key::Function(1),
-                            modifiers: KeyModifiers::NONE,
-                        }),
-                        Self::no_popup_mounted_clause(),
-                    ),
-                    Sub::new(
-                        SubEventClause::Keyboard(KeyEvent {
-                            code: Key::Function(10),
-                            modifiers: KeyModifiers::NONE,
-                        }),
-                        Self::no_popup_mounted_clause(),
-                    ),
-                    Sub::new(
-                        SubEventClause::Keyboard(KeyEvent {
-                            code: Key::Char('q'),
-                            modifiers: KeyModifiers::NONE,
-                        }),
-                        Self::no_popup_mounted_clause(),
-                    ),
-                    Sub::new(SubEventClause::WindowResize, SubClause::Always)
-                ]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .mount(
+                    Id::GlobalListener,
+                    Box::<components::GlobalListener>::default(),
+                    vec![
+                        Sub::new(
+                            SubEventClause::Keyboard(KeyEvent {
+                                code: Key::Esc,
+                                modifiers: KeyModifiers::NONE,
+                            }),
+                            Self::no_popup_mounted_clause(),
+                        ),
+                        Sub::new(
+                            SubEventClause::Keyboard(KeyEvent {
+                                code: Key::Char('h'),
+                                modifiers: KeyModifiers::NONE,
+                            }),
+                            Self::no_popup_mounted_clause(),
+                        ),
+                        Sub::new(
+                            SubEventClause::Keyboard(KeyEvent {
+                                code: Key::Function(1),
+                                modifiers: KeyModifiers::NONE,
+                            }),
+                            Self::no_popup_mounted_clause(),
+                        ),
+                        Sub::new(
+                            SubEventClause::Keyboard(KeyEvent {
+                                code: Key::Function(10),
+                                modifiers: KeyModifiers::NONE,
+                            }),
+                            Self::no_popup_mounted_clause(),
+                        ),
+                        Sub::new(
+                            SubEventClause::Keyboard(KeyEvent {
+                                code: Key::Char('q'),
+                                modifiers: KeyModifiers::NONE,
+                            }),
+                            Self::no_popup_mounted_clause(),
+                        ),
+                        Sub::new(SubEventClause::WindowResize, SubClause::Always)
+                    ]
+                )
+                .is_ok()
+        );
     }
 
     /// Returns a sub clause which requires that no popup is mounted in order to be satisfied
